/* NT7534 I2C LCD library! (for GTK-281)
   Display test program
   more info on www.weigu.lu

Copyright (C) 2018 Guy WEILER www.weigu.lu

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

some of this code was written by <cstone@pobox.com> originally and
some of this code was written by Limor Fried, Adafruit Industries
it is in the public domain.*/

#include "NT7534_I2C.h"

const uint8_t TEENSY_LED =  11;    // LED connected to digital pin 13
uint8_t BACKLIGHT = 6; // backlight

NT7534_I2C glcd(7, 6, 5, 4, 3); // rst, bl, en, rw. di

void setup() {
  //Serial.begin(9600);         // for debug
  //Serial.print("Hello");
  // initialize and set the contrast (brightness to 0x19 (0x01-0x3F)
  glcd.begin(0x19);
  pinMode(TEENSY_LED, OUTPUT);
  glcd.clear();
}

void loop() {
  glcd.pinPortB(BACKLIGHT, HIGH);
  digitalWrite(TEENSY_LED, HIGH);
  glcd.displaylogo(1);
  digitalWrite(TEENSY_LED, LOW);
  glcd.pinPortB(BACKLIGHT, LOW);
  glcd.clear();
  glcd.setall();      //fill black
  glcd.clear();
  testpixel();        // draw many pixel
  delay(100);
  testdrawline();     // draw many lines
  delay(100);
  testdrawrect();     // draw multiple rectangles
  glcd.clear();
  testfillrect();     // draw multiple filled rectangles
  delay(100);
  glcd.clear();
  testdrawcircle();   // draw mulitple circles
  delay(100);
  glcd.clear();
  testfillcircle();   // multiple black circles
  delay(100);
  glcd.clear();
  testprintchar1();     // draw the 128 characters in the font
  testprintchar2();     // draw the 128 characters in the font
  testprint();
  delay(100);
}

void testpixel() {
  for (uint8_t i=0; i<128; i+=4) {
    for (uint8_t j=0; j<64; j+=4) {
      delay(5);
      glcd.setpixel(i, j, BLACK);}}
  for (uint8_t i=0; i<128; i+=4) {
    for (uint8_t j=0; j<64; j+=4) {
      delay(5);
      glcd.setpixel(i, j, WHITE);}}}

void testdrawline() {
  for (uint8_t i=0; i<128; i+=8) {
    glcd.drawline(0, 0, i, 63, BLACK);}
  for (uint8_t i=0; i<64; i+=8) {
    glcd.drawline(0, 0, 127, i, BLACK);}
  delay(1000);
  for (uint8_t i=0; i<128; i+=8) {
    glcd.drawline(i, 63, 0, 0, WHITE);}
  for (uint8_t i=0; i<64; i+=8) {
    glcd.drawline(127, i, 0, 0, WHITE);}}

void testdrawrect(void) {
  for (uint8_t i=0; i<10; i+=2) glcd.drawrect(i, i, 128-i*2, 64-i*2, BLACK);
  for (uint8_t i=0; i<10; i+=2) glcd.drawrect(i, i, 128-i*2, 64-i*2, WHITE);
}

void testfillrect(void) {
  glcd.fillrect(40, 20, 20, 20, BLACK);
  glcd.fillrect(40, 20, 20, 20, WHITE);
}

void testdrawcircle(void) {
  for (uint8_t i=0; i<30; i+=5) {
    glcd.drawcircle(63, 31, i, BLACK);
  }
  for (uint8_t i=0; i<30; i+=5) {
    glcd.drawcircle(63, 31, i, WHITE);
  }
}

void testfillcircle(void) {
  for (uint8_t i=0; i<128; i+=20) { glcd.fillcircle(i, 32, 10, BLACK); }
  for (uint8_t i=0; i<128; i+=20) { glcd.fillcircle(i, 32, 10, WHITE); }
}

void testprintchar1(void) {
  for (int i=0; i < 128; i++) {
    glcd.printchar(((i) % 21) * 6, (i)/21, i);
  }
  for (int i=0; i < 128; i++) {
    glcd.clearchar(((i) % 21) * 6, (i)/21);
  }
}

void testprintchar2(void) {
  for (int i=128; i < 259; i++) {
    glcd.printchar(((i-128) % 21) * 6, (i-128)/21, i);
  }
  for (int i=128; i < 259; i++) {
    glcd.clearchar(((i-128) % 21) * 6, (i-128)/21);
  }
}

void testprint(void) {
  uint8_t j=0;
  for (uint8_t i=0; i < 6; i++) {
    glcd.print(i, j, "CREATIVE-LAB");
    glcd.print(i, j+1, "by LAM!!");
    delay(700);
    glcd.clearstring(i, j, "CREATIVE-LAB");
    glcd.clearstring(i, j+1, "by LAM!!");
    j++;
  }
}
